@@ -4,8 +4,14 @@ import sys
 
 
 def typingprint(text):
-    """Typingprint types out stuff"""
+    """Types out a string of text
+    
+    Args:
+        Print (str): What to type out"
+        
+    """
     for character in text:
         sys.stdout.write(character)
         sys.stdout.flush()
-        time.sleep(0.05)
\ No newline at end of file
+        time.sleep(0.05)
+        
\ No newline at end of file
